pytilities.aop._aopdescriptor — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »

# pytilities.aop._aopdescriptor

`pytilities.aop._aopdescriptor.` `_AOPDescriptor`

  Allows advice to be given to a descriptor or attribute.

  Follows advice rules as described by Advisor

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »